pub trait PathBuilderObject {
// Required methods
fn set_fill_type(&mut self, fill_type: FillType);
fn move_to(&mut self, location: PixelPoint);
fn line_to(&mut self, location: PixelPoint);
fn quadratic_curve_to(
&mut self,
control_point: PixelPoint,
end_point: PixelPoint,
);
fn cubic_curve_to(
&mut self,
control_point_1: PixelPoint,
control_point_2: PixelPoint,
end_point: PixelPoint,
);
fn add_rect(&mut self, rect: PixelRect);
fn add_rounded_rect(
&mut self,
rect: PixelRect,
rounding_radii: &RoundingRadii,
);
fn add_oval(&mut self, oval_bounds: PixelRect);
fn add_arc(
&mut self,
oval_bounds: PixelRect,
start_angle_degrees: f32,
end_angle_degrees: f32,
);
fn close(&mut self);
fn build(self) -> Box<dyn PathObject>;
fn build_copy(&mut self) -> Box<dyn PathObject>;
}Required Methods
Sourcefn set_fill_type(&mut self, fill_type: FillType)
fn set_fill_type(&mut self, fill_type: FillType)
Sets the fill type.
Sourcefn move_to(&mut self, location: PixelPoint)
fn move_to(&mut self, location: PixelPoint)
Move the cursor to the specified location.
Sourcefn line_to(&mut self, location: PixelPoint)
fn line_to(&mut self, location: PixelPoint)
Add a line segment from the current cursor location to the given location. The cursor location is updated to be at the endpoint.
Sourcefn quadratic_curve_to(
&mut self,
control_point: PixelPoint,
end_point: PixelPoint,
)
fn quadratic_curve_to( &mut self, control_point: PixelPoint, end_point: PixelPoint, )
Add a quadratic bezier curve from whose start point is the cursor to the specified end point using the a single control point. The cursor location is updated to be at the endpoint.
Sourcefn cubic_curve_to(
&mut self,
control_point_1: PixelPoint,
control_point_2: PixelPoint,
end_point: PixelPoint,
)
fn cubic_curve_to( &mut self, control_point_1: PixelPoint, control_point_2: PixelPoint, end_point: PixelPoint, )
Add a cubic bezier curve whose start point is current cursor location to the specified end point using the two specified control points. The cursor location is updated to be at the endpoint.
Sourcefn add_rounded_rect(&mut self, rect: PixelRect, rounding_radii: &RoundingRadii)
fn add_rounded_rect(&mut self, rect: PixelRect, rounding_radii: &RoundingRadii)
Add a rounded rect with potentially non-uniform radii to the path.
Sourcefn add_arc(
&mut self,
oval_bounds: PixelRect,
start_angle_degrees: f32,
end_angle_degrees: f32,
)
fn add_arc( &mut self, oval_bounds: PixelRect, start_angle_degrees: f32, end_angle_degrees: f32, )
Add an arc to the path.
Sourcefn build(self) -> Box<dyn PathObject>
fn build(self) -> Box<dyn PathObject>
Builds the path.
Sourcefn build_copy(&mut self) -> Box<dyn PathObject>
fn build_copy(&mut self) -> Box<dyn PathObject>
Create a new path by copying the existing built-up path. The existing path can continue being added to.